@@ -57,8 +57,10 @@
 #include <winsock.h>
 #include <io.h>
 #include <time.h>
+#include <errno.h>
 #else
 #include <dirent.h>
+#include <sys/errno.h>
 #endif
 
 #include "utilities.h"
@@ -146,9 +148,10 @@ int seed_prng( int bytes )
 **
 ******************************************************************************/
 
-char * hash_file_md5( const char *file_path, FILE *file,    
-                      char *buffer, int buffer_size )
+int hash_file_md5( const char *file_path, FILE *file,    
+                   char *buffer, int buffer_size )
 {
+    int fno;
     FILE *file_to_hash  = file;
     MD5_CTX context;
     unsigned char digest[MD5_DIGEST_LENGTH];
@@ -159,12 +162,12 @@ char * hash_file_md5( const char *file_path, FILE *file,
     unsigned char hash_buffer[BUFFER_SIZE];
     char file_hash[33];
 
-    if( ( file_path != NULL ) && ( buffer != NULL ) &&
-        ( buffer_size >= MAX_CHECKSUM_LENGTH ) )
+    if ( ( file_path != NULL ) && ( buffer != NULL ) &&
+         ( buffer_size >= MAX_CHECKSUM_LENGTH ) )
     {
         /* see if we were given a file descriptor. */
 
-        if( file_to_hash == NULL )
+        if ( file_to_hash == NULL )
         {
             file_to_hash = fopen( file_path, FILE_OPEN_READ_FLAGS );
         }
@@ -174,49 +177,66 @@ char * hash_file_md5( const char *file_path, FILE *file,
             fseek( file_to_hash, 0, SEEK_SET );
         }
 
-        if( file_to_hash != NULL )
+        if ( file_to_hash == NULL )
         {
-            /* initialize the md5 library and our hash string */
-            /* which is 32 bytes long for md5.                */
-
-            MD5_Init( &context );
-
-            while(1)
-            {
-                burst = read( fileno( file_to_hash ),
-                              hash_buffer, BUFFER_SIZE );
-
-                if( burst <= 0 )
-                {
-                    break;
-                }
-
-                MD5_Update( &context, hash_buffer, (unsigned long)burst );
-            }
-
-            MD5_Final( &( digest[0] ), &context );
-
-            for ( index = 0; index < MD5_DIGEST_LENGTH; index++)
-            {
-                osi_snprintf( &file_hash[index * 2], 3, "%02x", digest[index] );
-            }
-
-            file_hash[32] = '\0';
-
-            /* if we didn't open it, don't close it. */
-
-            if( file == NULL )
-            {
-                fclose( file_to_hash );
-            }
-
-            osi_strlcpy( buffer, file_hash, buffer_size );
-
-            return buffer;
+#ifdef WIN32
+            return GetLastError();
+#else
+            return errno;
+#endif
         }
+
+        fno = fileno( file_to_hash );
+
+        /* initialize the md5 library and our hash string */
+        /* which is 32 bytes long for md5.                */
+
+        MD5_Init( &context );
+
+        while (1)
+        {
+            burst = read( fno, hash_buffer, BUFFER_SIZE );
+
+            if ( burst == 0 )
+            {
+                break;
+            }
+
+            else if ( burst < 0 )
+            {
+#ifdef WIN32
+                int e = GetLastError();
+#else
+                int e = errno;
+#endif
+                memset( buffer, 0, buffer_size );
+                return e;
+            }
+
+            MD5_Update( &context, hash_buffer, (unsigned long)burst );
+        }
+
+        MD5_Final( &( digest[0] ), &context );
+
+        for ( index = 0; index < MD5_DIGEST_LENGTH; index++)
+        {
+            osi_snprintf( &file_hash[index * 2], 3, "%02x", digest[index] );
+        }
+
+        file_hash[32] = '\0';
+
+        /* if we didn't open it, don't close it. */
+
+        if ( file == NULL )
+        {
+            fclose( file_to_hash );
+        }
+
+        osi_strlcpy( buffer, file_hash, buffer_size );
+        return 0;
     }
 
-    return NULL;
+    return -1;
 }
 
 /******************************************************************************
@@ -227,9 +247,11 @@ char * hash_file_md5( const char *file_path, FILE *file,
 **
 ******************************************************************************/
 
-char * hash_file_sha( const char *file_path, FILE *file,
+int hash_file_sha( const char *file_path, FILE *file,
                       char *buffer, int buffer_size )
 {
+    int fno;
+
     FILE *file_to_hash  = file;
     SHA_CTX context;
     unsigned char digest[SHA_DIGEST_LENGTH];
@@ -253,49 +275,66 @@ char * hash_file_sha( const char *file_path, FILE *file,
             fseek( file_to_hash, 0, SEEK_SET );
         }
 
-        if( file_to_hash != NULL )
+        if( file_to_hash == NULL )
         {
-            /* initialize the sha library and our hash string */
-            /* which is 40 bytes long for sha.                */
-
-            SHA1_Init( &context );
-
-            while(1)
-            {
-                burst = read( fileno( file_to_hash ),
-                              hash_buffer, BUFFER_SIZE );
-
-                if( burst <= 0 )
-                {
-                    break;
-                }
-
-                SHA1_Update( &context, hash_buffer, (unsigned long)burst );
-            }
-
-            SHA1_Final( &( digest[0] ), &context );
-
-            for ( index = 0; index < SHA_DIGEST_LENGTH; index++ )
-            {
-                osi_snprintf( &file_hash[index * 2], 3, "%02x", digest[index] );
-            }
-
-            file_hash[40] = '\0';
-
-            /* if we didn't open it, don't close it. */
-
-            if( file == NULL )
-            {
-                fclose( file_to_hash );
-            }
-
-            osi_strlcpy( buffer, file_hash, buffer_size );
-
-            return buffer;
+#ifdef WIN32
+            return GetLastError();
+#else
+            return errno;
+#endif
         }
+
+        fno = fileno( file_to_hash );
+
+        /* initialize the sha library and our hash string */
+        /* which is 40 bytes long for sha.                */
+
+        SHA1_Init( &context );
+
+        while (1)
+        {
+            burst = read( fileno( file_to_hash ), hash_buffer, BUFFER_SIZE );
+
+            if( burst == 0 )
+            {
+                break;
+            }
+
+            if ( burst < 0 )
+            {
+#ifdef WIN32
+                int e = GetLastError();
+#else
+                int e = errno;
+#endif
+                memset( buffer, 0, buffer_size );
+                return e;
+            }
+
+            SHA1_Update( &context, hash_buffer, (unsigned long)burst );
+        }
+
+        SHA1_Final( &( digest[0] ), &context );
+
+        for ( index = 0; index < SHA_DIGEST_LENGTH; index++ )
+        {
+            osi_snprintf( &file_hash[index * 2], 3, "%02x", digest[index] );
+        }
+
+        file_hash[40] = '\0';
+
+        /* if we didn't open it, don't close it. */
+
+        if( file == NULL )
+        {
+            fclose( file_to_hash );
+        }
+
+        osi_strlcpy( buffer, file_hash, buffer_size );
+        return 0;
     }
 
-    return NULL;
+    return -1;
 }
 
 /******************************************************************************
@@ -306,9 +345,10 @@ char * hash_file_sha( const char *file_path, FILE *file,
 **
 ******************************************************************************/
 
-char * hash_file_ripemd( const char *file_path, FILE *file,
-                         char *buffer, int buffer_size )
+int hash_file_ripemd( const char *file_path, FILE *file,
+                      char *buffer, int buffer_size )
 {
+    int fno;
     FILE *file_to_hash  = file;
     RIPEMD160_CTX context;
     unsigned char digest[RIPEMD160_DIGEST_LENGTH];
@@ -332,49 +372,66 @@ char * hash_file_ripemd( const char *file_path, FILE *file,
             fseek( file_to_hash, 0, SEEK_SET );
         }
 
-        if( file_to_hash != NULL )
+        if( file_to_hash == NULL )
         {
-            /* initialize the ripemd library and our hash string */
-            /* which is 80 bytes long for ripemd.                */
-
-            RIPEMD160_Init( &context );
-
-            while(1)
-            {
-                burst = read( fileno( file_to_hash ),
-                              hash_buffer, BUFFER_SIZE );
-
-                if( burst <= 0 )
-                {
-                    break;
-                }
-
-                RIPEMD160_Update( &context, hash_buffer, (unsigned long)burst );
-            }
-
-            RIPEMD160_Final( &( digest[0] ), &context );
-
-            for ( index = 0; index < RIPEMD160_DIGEST_LENGTH; index++)
-            {
-                osi_snprintf( &file_hash[index * 2], 3, "%02x", digest[index] );
-            }
-
-            file_hash[80] = '\0';
-
-            /* if we didn't open it, don't close it. */
-
-            if( file == NULL )
-            {
-                fclose( file_to_hash );
-            }
-
-            osi_strlcpy( buffer, file_hash, buffer_size );
-
-            return buffer;
+#ifdef WIN32
+            return GetLastError();
+#else
+            return errno;
+#endif
         }
+
+        fno = fileno( file_to_hash );
+
+        /* initialize the ripemd library and our hash string */
+        /* which is 80 bytes long for ripemd.                */
+
+        RIPEMD160_Init( &context );
+
+        while (1)
+        {
+            burst = read( fileno( file_to_hash ), hash_buffer, BUFFER_SIZE );
+
+            if( burst == 0 )
+            {
+                break;
+            }
+
+            if ( burst < 0 )
+            {
+#ifdef WIN32
+                int e = GetLastError();
+#else
+                int e = errno;
+#endif
+                memset( buffer, 0, buffer_size );
+                return e;
+            }
+
+            RIPEMD160_Update( &context, hash_buffer, (unsigned long)burst );
+        }
+
+        RIPEMD160_Final( &( digest[0] ), &context );
+
+        for ( index = 0; index < RIPEMD160_DIGEST_LENGTH; index++)
+        {
+            osi_snprintf( &file_hash[index * 2], 3, "%02x", digest[index] );
+        }
+
+        file_hash[80] = '\0';
+
+        /* if we didn't open it, don't close it. */
+
+        if( file == NULL )
+        {
+            fclose( file_to_hash );
+        }
+
+        osi_strlcpy( buffer, file_hash, buffer_size );
+        return 0;
     }
 
-    return NULL;
+    return -1;
 }
 
 
