@@ -71,39 +71,24 @@ struct n_keywords
     int  type;
 };
 
-/*
-extern struct n_keywords cmp_keywords[];
-extern struct n_keywords cmp_descriptions[];
-*/
-
-
 typedef struct OSI_CMP_FILTER
 {
-    char host[MAX_HOSTNAME_LENGTH];
-    char path[MAX_PATH_LENGTH];
-
-    osi_uint64 type; 
-    osi_uint64 mask;
+    char exclude[MAX_PATH_LENGTH];
     
 } OSI_CMP_FILTER;
 
-void wrap_cmp_filter( OSI_CMP_FILTER *filter );
-void unwrap_cmp_filter( OSI_CMP_FILTER *filter );
-
-unsigned int pack_cmp_filter( OSI_CMP_FILTER *filter, char *buffer,
-                                 int buffer_size );
-
-void unpack_cmp_filter( OSI_CMP_FILTER *filter, char *buffer,
-                           int buffer_size );
-
 
 void print_cmp_filter( OSI_CMP_FILTER *filter );
 void print_cmp_attribute_mask( osi_uint64 attr_list );
 void print_valid_cmp_filter_attributes();
 
-
 char * osi_get_name_for_cmp_attribute( osi_uint64 attr );
 unsigned long mask_from_cmp_keywords( const char *keywords );
 
+unsigned int pack_cmp_filter( OSI_CMP_FILTER *filter, char *buffer,
+                              int buffer_size );
+
+void unpack_cmp_filter( OSI_CMP_FILTER *filter, char *buffer,
+                        int buffer_size );
 
 #endif
