@@ -359,14 +359,20 @@ void process_kmods_solaris( SCANNER *scanner )
         {
             m.mi_name[MODMAXNAMELEN-1] = 0;
 
+            initialize_scan_record( (SCAN_RECORD *)&record,
+                                    SCAN_RECORD_TYPE_TEXT_1 );
+
             osi_snprintf( record.name, sizeof( record.name ),
                           "kern:%d,%d", m.mi_id, index );
 
+            osi_strlcpy( record.module_name, MODULE_NAME,
+                         sizeof( record.module_name ) );
+
             if( m.mi_msinfo[index].msi_linkinfo[0] == 0 )
             {
 		        osi_snprintf( record.data, sizeof( record.data ),
-				              "id=%d;loadcount=%d;state=%d;name=%s",
-				              m.mi_id, m.mi_loadcnt, m.mi_state, m.mi_name );
+				     "id=%d;loadcount=%d;state=%d;name=%s",
+		           m.mi_id, m.mi_loadcnt, m.mi_state, m.mi_name );
 
         		send_scan_data( scanner, (SCAN_RECORD *)&record );
                 break;
@@ -374,11 +380,6 @@ void process_kmods_solaris( SCANNER *scanner )
 
             p = m.mi_msinfo[index].msi_p0;
 
-            if( p == -1 )
-            {
-                p = -1;
-            }
-
             m.mi_msinfo[index].msi_linkinfo[MODMAXNAMELEN-1] = 0;
 
             osi_snprintf( record.data, sizeof( record.data ),
