@@ -459,7 +459,9 @@ void process_ports_linux( SCANNER *scanner )
 {
     process_proc_file( scanner, TCP_FILE );
     process_proc_file( scanner, TCP6_FILE );
-    process_proc_file( scanner, UDP_FILE );
+
+    /* disabled for now.
+    process_proc_file( scanner, UDP_FILE ); */
 }
 
 #endif
