@@ -119,11 +119,15 @@
 #define LOG_ID_SCHEDULER_FAIL       803
 #define LOG_ID_SCHEDULER_INFO       804
 
+#define LOG_ID_LOG_APP_FAILURE      900
+
 
 void log_error( int id, const char *host, const char *message, ... );
 void log_info( int id, const char *host, const char *message, ... );
 void log_warning( int id, const char *host, const char *message, ... );
 
-void log_cmp_message( int id, OSI_DB_CTX *context, const char *message, ... );
+int log_cmp_message( int id, OSI_DB_CTX *context, const char *message, ... );
+
+osi_bool log_payload_is_filtered( const char *payload );
 
 #endif
