@@ -38,8 +38,8 @@ osi_bool name_regex( const char *name, const char *pattern )
 }
 
 
-#define BASE "C:\\Program Files\\Altiris\\eXpress\\NS Client\\Queue\\NSA-SJC-003.CISCO.COM"
-#define CASE ".*NSA-SJC-003*"
+#define BASE "[213][local][cmp][/etc/resolv.conf][mtime]"
+#define CASE "\\[^/etc\\]*\\[mtime|ctime\\]"
 
 int main()
 {
